#
# spec file for package perl-XML-Bare
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-XML-Bare
Version:        0.53
Release:        lp151.2.3
%define cpan_name XML-Bare
Summary:        Minimal XML parser implemented via a C state engine
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/XML-Bare/
Source:         http://www.cpan.org/authors/id/C/CO/CODECHILD/%{cpan_name}-%{version}.tar.gz
Patch0:         fix-pointers.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.94
%{perl_requires}

%description
This module is a 'Bare' XML parser. It is implemented in C. The parser
itself is a simple state engine that is less than 500 lines of C. The
parser builds a C struct tree from input text. That C struct tree is
converted to a Perl hash by a Perl function that makes basic calls back to
the C to go through the nodes sequentially.

The parser itself will only cease parsing if it encounters tags that are
not closed properly. All other inputs will parse, even invalid inputs. To
allowing checking for validity, a schema checker is included in the module
as well.

The schema format is custom and is meant to be as simple as possible. It is
based loosely around the way multiplicity is handled in Perl regular
expressions.

%prep
%setup -q -n %{cpan_name}-%{version}
%patch0 -p1
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Mon Aug  5 2013 coolo@suse.com
- add fix-pointers.diff to fix build on factory
* Sat Jul 27 2013 coolo@suse.com
- updated to 0.53
  - Remove executable permissions from files that shouldn't have them.
  - Added shebang to main Bare.pm file ( apparently some people want this )
  - Correct line endings to unix style on parser.c
  - Improved simplify function that works properly with trees instead of just a single level
  - Added hash2xml to quickly convert recursing hashes into XML
  - Added proper binmode setting when outputting XML to address deficiences on Win32 ( such as failing Strawberry perl due to line endings )
  - Added evil OS check in file writing code to address differences in how files must be opened to write utf8 on win32 versus linux/cygwin.
  - Added note regarding using utf8 flag instead of using encoding(utf8)
  - Altered UTF8 test to also write XML containing UTF8 to a file.
  - New 'unsafe' parsing mode, giving a 30%% speed increase with some downfalls
  - New 'read_more' function, allowing more data to be read in before parsing into a tree
  - Fixed some memory leaks
  - Added 'Controversy' section to documentation
  - Updated speed comparisons for feed2.xml, adding a comparison against XML::Fast as well
    as a comparison of running in 'unsafe' mode.
  - Spelling correction
  - "Modernized" file handling using my variables
  - Remove debugging print statements that were left in
  - Include the new test cases in the distribution
  - Fixes to find_by_perl
    Can now be accessed in an object or namespace flexibly.
    Now ignores case of keys.
    Keys with underscores can be used.
    Will work properly when passed a single node instead of an array reference of nodes.
  - Fixes to xget
    Method of deferencing has been changed to be compatible with newer versions of perl ( 5.10.2+ )
  - Fixed handling of nodes named 'value'; they will no longer crash the XS code
  - Added a new function similar to new called 'simple', that works in the same way but automatically uses the 'simple' parser
  - Altered handling of node values in simple mode, so that it stores values when mixed with nodes or atttributes under 'content' ( like XML::Simple )
    This feature was requested by users so it has been added. Note that it only does this when the value is not composed of just spaces and carriage returns.
  - Revert code back to 0.45 version
    Changes lost in the process:
    Content is not stored in the 'content' key any more; it is stored as the node itself when the node contains nothing else. As God intended.
    Memory leak fixes
    Quote handling
  - Code copyright returned fully to David Helkowski; any changes by other parties have been discarded. Any code ported in from other open source projects removed.
    This has been done intentionally so as to make it possible to relicense the software commerically.
  - XS code modofied to work in a multi-threaded environment
  - Reverting Makefile.PL back to original wierd hackish fixes. They are there for specific reasons.
* Fri Feb 10 2012 vcizek@suse.com
- update to 0.47
  - Preping release unchanged from trial release.
    The 0.45 release and previous set particular compile options for several different
    platforms.  My release refactoring stripped the Makefile.PL customisations, however
    it appears these are not needed by any of the smoker CPANTS systems, so am releasing
    with really basic compilation driver - see how it goes...
  - Bug #49906 Simple mode reports content of empty node as integer 1
  - Bug #52762 XML::Simple compatibility mode doesn't support CDATA with attributes
  - Bug #52832 Several memory leaks
  - XML quote decoding on XML read
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Mar 15 2011 cfarrell@novell.com
- license update: GPLv2+ or Artistic
  Rewrite spec file license in new syntax and highlight that this package is _not_ the standard Perl license but GPLv2+ (note the 2) or Artistic. See the package README
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 0.45
  * Missing UTF8 test files now included
  * XML Saving functionality now does size checks to ensure concurrency
    issues do not corrupt XML.
  * Linking under Solaris should now be fixed
  * Line number defines removed from XS compilation to attempt to
    fix some strange compilation problems.
  * Self closing nodes now printed by xml function
  * UTF8 Handling fixed; thanks go to Nigel Metheringham for the fix
    recommendation as well as the test files
  * Static linking has been fixed
  * 'cc' now used properly in cases where 'gcc' is absent
* Wed Mar 18 2009 anicka@suse.cz
- update to 0.43
  * Added a new test to detect fixed problem
  * A number of memory leaks have been fixed
  - XML files included for benchmarking have been replaced with
    dummy test data to avoid licensing problems.
  * Perl code has been optimized
  * Fixed problem with merge function
  * Added tohtml output
  * Added flag to indicate node read in as CDATA
* Tue Jan 20 2009 anicka@suse.cz
- update to 0.40
  * Added schema checking functionality
  * Fixed parsing of nodes with more than one comment block
  * Added error checking to ensure properly closed tags
  * Fixed parsing of attributes without values
* Fri Jul 25 2008 anicka@suse.cz
- update to 0.30
  * Add new parsing mode, simple, which simulates XML::Simple.
  * New function add_node_after
  * Fixed node ordering such that node order is preserved
  * Altered xml output so that it cleans extraneous input spacing
    and indents mixed values properly.
  * Added prereqs to Makefile.pl
  * Added Test::POD and Test::POD::Coverage tests
  * Fixed incorrect pointer type cast in parser.c
  * Rewrote benchmark system to use templated benchmarking
* Thu Jun 26 2008 anicka@suse.cz
- fix permissions (bnc#403978)
* Thu Dec 13 2007 anicka@suse.cz
- update to 0.27
  * changes in makefile.pl
  * added tests and examples
  * bugfixes
  * Comments are no longer completely ignored.
  * forcearray, simplify  function has been added
  * mixed XML supported
  * C Parser has been revised greatly in order to make it faster.
  * Code that creates Perl hash from parsed XML structure has been
  rewritten in XS instead of Perl.
* Fri Jul 13 2007 pcerny@suse.cz
- package created (v 0.11) - requested for YaST
